/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2005 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp05nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp05nid ;

DATA library.&dataset ;
INFILE datafile LRECL=4732;
INPUT
   DISGORGE  1              CPIDN  2-5               AMENDYR  6-9          
   BUSTEXT $ 10             OWNSTEXT $ 11            FINSTXT $ 12-63       
   FINDOTXT $ 64            OFENTXT1 $ 65-103        OFENTXT2 $ 104        
   OFENTXT3 $ 105           PRMONTXT $ 106-202       ORDERTXT $ 203-302    
   OUTSOURC $ 303           PSR  304                 JANDC  305            
   PLEA  306                REASONS  307             INDICT  308           
   SENTRANS  309            WRKSHT  310              INCORPYR  311-314     
   INCORLOC  315            ORGTYPE  316             BUSCLAS  317-320      
   FTEMNUM  321-324         FTEMSIGN  325            SELFREP  326          
   HSMISCND  327            PRCRIME  328             PRCIVIL  329          
   OWNSTRCT  330            FINSTDS  331             FINSTDO  332          
   PRIMOFF  333-334         NOCOUNTS  335-337        SOURCES  338          
   OFFLVL  339-340          DETBFINE  341            TOLERNCE  342         
   HISTORY  343             VIOLATE  344             OBSTRUCT  345         
   COMPLY  346              ACCEPT  347-348          CCULPSCO  349         
   FCULPSCO  350-351        MINFINML  352-354        MAXFINML  355-357     
   DISPOSIT  358            PROBATN  359-360         COFI  361             
   PROBMON  362             ORDERCE  363             TYPEOTHS  364-365     
   CRIMPURP  366            CANTPAY  367             DEPSOR  368           
   ADJOFL1  369-370         ADJOFL2  371-372         ADJOFL3  373          
   ADJOFLHI  374-375        ADJ_B1  376-377          ADJ_B2  378-379       
   ADJ_B3  380              ADJ_BHI  381-382         ADJ_C1  383-384       
   ADJ_C2  385              ADJ_C3  386              ADJ_CHI  387-388      
   ADJ_D1  389-391          ADJ_D2  392              ADJ_D3  393           
   ADJ_DHI  394-396         ADJ_E1  397              ADJ_E2  398           
   ADJ_E3  399              ADJ_EHI  400             ADJ_F1  401           
   ADJ_F2  402              ADJ_F3  403              ADJ_FHI  404          
   ADJ_G1  405              ADJ_G2  406              ADJ_G3  407           
   ADJ_GHI  408             ADJ_H1  409              ADJ_H2  410           
   ADJ_H3  411              ADJ_HHI  412             ADJ_I1  413           
   ADJ_I2  414              ADJ_I3  415              ADJ_IHI  416          
   ADJ_J1  417              ADJ_J2  418              ADJ_J3  419           
   ADJ_JHI  420             ADJ_K1  421              ADJ_K2  422           
   ADJ_K3  423              ADJ_KHI  424             ADJ_L1  425           
   ADJ_L2  426              ADJ_L3  427              ADJ_LHI  428          
   ADJ_M1  429              ADJ_M2  430              ADJ_M3  431           
   ADJ_MHI  432             ADJ_N1  433              ADJ_N2  434           
   ADJ_N3  435              ADJ_NHI  436             ADJ_O1  437           
   ADJ_O2  438              ADJ_O3  439              ADJ_OHI  440          
   ADJ_P1  441              ADJ_P2  442              ADJ_P3  443           
   ADJ_PHI  444             BASADJ1  445             BASADJ2  446          
   BASADJ3  447             BASADJHI  448            BASE1  449-450        
   BASE2  451-452           BASE3  453               BASEHI  454-455       
   ADJOFR1  456-457         ADJOFR2  458             ADJOFR3  459          
   ADJOFRHI  460-461        ADJR_B1  462-463         ADJR_B2  464          
   ADJR_B3  465             ADJR_BHI  466-467        ADJR_C1  468          
   ADJR_C2  469             ADJR_C3  470             ADJR_CHI  471         
   ADJR_D1  472             ADJR_D2  473             ADJR_D3  474          
   ADJR_DHI  475            ADJR_E1  476             ADJR_E2  477          
   ADJR_E3  478             ADJR_EHI  479            ADJR_F1  480          
   ADJR_F2  481             ADJR_F3  482             ADJR_FHI  483         
   ADJR_G1  484             ADJR_G2  485             ADJR_G3  486          
   ADJR_GHI  487            ADJR_H1  488             ADJR_H2  489          
   ADJR_H3  490             ADJR_HHI  491            ADJR_I1  492          
   ADJR_I2  493             ADJR_I3  494             ADJR_IHI  495         
   ADJR_J1  496             ADJR_J2  497             ADJR_J3  498          
   ADJR_JHI  499            ADJR_K1  500             ADJR_K2  501          
   ADJR_K3  502             ADJR_KHI  503            ADJR_L1  504          
   ADJR_L2  505             ADJR_L3  506             ADJR_LHI  507         
   ADJR_M1  508             ADJR_M2  509             ADJR_M3  510          
   ADJR_MHI  511            ADJR_N1  512             ADJR_N2  513          
   ADJR_N3  514             ADJR_NHI  515            ADJR_O1  516          
   ADJR_O2  517             ADJR_O3  518             ADJR_OHI  519         
   ADJR_P1  520             ADJR_P2  521             ADJR_P3  522          
   ADJR_PHI  523            BASADR1  524             BASADR2  525          
   BASADR3  526             BASADRHI  527            BASER1  528-529       
   BASER2  530              BASER3  531              BASERHI  532-533      
   ADJOFS1  534-535         ADJOFS2  536-537         ADJOFS3  538          
   ADJOFSHI  539-540        ADJS_B1  541-542         ADJS_B2  543-544      
   ADJS_B3  545             ADJS_BHI  546-547        ADJS_C1  548-549      
   ADJS_C2  550             ADJS_C3  551             ADJS_CHI  552-553     
   ADJS_D1  554-556         ADJS_D2  557             ADJS_D3  558          
   ADJS_DHI  559-561        ADJS_E1  562             ADJS_E2  563          
   ADJS_E3  564             ADJS_EHI  565            ADJS_F1  566          
   ADJS_F2  567             ADJS_F3  568             ADJS_FHI  569         
   ADJS_G1  570             ADJS_G2  571             ADJS_G3  572          
   ADJS_GHI  573            ADJS_H1  574             ADJS_H2  575          
   ADJS_H3  576             ADJS_HHI  577            ADJS_I1  578          
   ADJS_I2  579             ADJS_I3  580             ADJS_IHI  581         
   ADJS_J1  582             ADJS_J2  583             ADJS_J3  584          
   ADJS_JHI  585            ADJS_K1  586             ADJS_K2  587          
   ADJS_K3  588             ADJS_KHI  589            ADJS_L1  590          
   ADJS_L2  591             ADJS_L3  592             ADJS_LHI  593         
   ADJS_M1  594             ADJS_M2  595             ADJS_M3  596          
   ADJS_MHI  597            ADJS_N1  598             ADJS_N2  599          
   ADJS_N3  600             ADJS_NHI  601            ADJS_O1  602          
   ADJS_O2  603             ADJS_O3  604             ADJS_OHI  605         
   ADJS_P1  606             ADJS_P2  607             ADJS_P3  608          
   ADJS_PHI  609            BASADS1  610             BASADS2  611          
   BASADS3  612             BASADSHI  613            BASES1  614-615       
   BASES2  616-617          BASES3  618              BASESHI  619-620      
   ADJOFC1  621             ADJOFC2  622             ADJOFC3  623          
   ADJOFCHI  624            ADJC_B1  625             ADJC_B2  626          
   ADJC_B3  627             ADJC_BHI  628            ADJC_C1  629          
   ADJC_C2  630             ADJC_C3  631             ADJC_CHI  632         
   ADJC_D1  633             ADJC_D2  634             ADJC_D3  635          
   ADJC_DHI  636            ADJC_E1  637             ADJC_E2  638          
   ADJC_E3  639             ADJC_EHI  640            ADJC_F1  641          
   ADJC_F2  642             ADJC_F3  643             ADJC_FHI  644         
   ADJC_G1  645             ADJC_G2  646             ADJC_G3  647          
   ADJC_GHI  648            ADJC_H1  649             ADJC_H2  650          
   ADJC_H3  651             ADJC_HHI  652            ADJC_I1  653          
   ADJC_I2  654             ADJC_I3  655             ADJC_IHI  656         
   ADJC_J1  657             ADJC_J2  658             ADJC_J3  659          
   ADJC_JHI  660            ADJC_K1  661             ADJC_K2  662          
   ADJC_K3  663             ADJC_KHI  664            ADJC_L1  665          
   ADJC_L2  666             ADJC_L3  667             ADJC_LHI  668         
   ADJC_M1  669             ADJC_M2  670             ADJC_M3  671          
   ADJC_MHI  672            ADJC_N1  673             ADJC_N2  674          
   ADJC_N3  675             ADJC_NHI  676            ADJC_O1  677          
   ADJC_O2  678             ADJC_O3  679             ADJC_OHI  680         
   ADJC_P1  681             ADJC_P2  682             ADJC_P3  683          
   ADJC_PHI  684            BASADC1  685             BASADC2  686          
   BASADC3  687             BASADCHI  688            BASEC1  689           
   BASEC2  690              BASEC3  691              BASECHI  692          
   ADJL_B1 $ 693            ADJL_B2 $ 694            ADJL_B3 $ 695         
   ADJL_BHI $ 696           ADJL_C1 $ 697-698        ADJL_C2 $ 699         
   ADJL_C3 $ 700            ADJL_CHI $ 701-702       ADJL_D1 $ 703         
   ADJL_D2 $ 704            ADJL_D3 $ 705            ADJL_DHI $ 706        
   ADJL_E1 $ 707            ADJL_E2 $ 708            ADJL_E3 $ 709         
   ADJL_EHI $ 710           ADJL_F1 $ 711            ADJL_F2 $ 712         
   ADJL_F3 $ 713            ADJL_FHI $ 714           ADJL_G1 $ 715         
   ADJL_G2 $ 716            ADJL_G3 $ 717            ADJL_GHI $ 718        
   ADJL_H1 $ 719            ADJL_H2 $ 720            ADJL_H3 $ 721         
   ADJL_HHI $ 722           ADJL_I1 $ 723            ADJL_I2 $ 724         
   ADJL_I3 $ 725            ADJL_IHI $ 726           ADJL_J1 $ 727         
   ADJL_J2 $ 728            ADJL_J3 $ 729            ADJL_JHI $ 730        
   ADJL_K1 $ 731-732        ADJL_K2 $ 733            ADJL_K3 $ 734         
   ADJL_KHI $ 735-736       ADJL_L1 $ 737            ADJL_L2 $ 738         
   ADJL_L3 $ 739            ADJL_LHI $ 740           ADJL_M1 $ 741         
   ADJL_M2 $ 742            ADJL_M3 $ 743            ADJL_MHI $ 744        
   ADJL_N1 $ 745            ADJL_N2 $ 746            ADJL_N3 $ 747         
   ADJL_NHI $ 748           ADJL_O1 $ 749            ADJL_O2 $ 750         
   ADJL_O3 $ 751            ADJL_OHI $ 752           ADJL_P1 $ 753         
   ADJL_P2 $ 754            ADJL_P3 $ 755            ADJL_PHI $ 756        
   BASEL1 $ 757             BASEL2 $ 758             BASEL3 $ 759          
   BASELHI $ 760            ADRL_B1 $ 761            ADRL_B2 $ 762         
   ADRL_B3 $ 763            ADRL_BHI $ 764           ADRL_C1 $ 765         
   ADRL_C2 $ 766            ADRL_C3 $ 767            ADRL_CHI $ 768        
   ADRL_D1 $ 769            ADRL_D2 $ 770            ADRL_D3 $ 771         
   ADRL_DHI $ 772           ADRL_E1 $ 773            ADRL_E2 $ 774         
   ADRL_E3 $ 775            ADRL_EHI $ 776           ADRL_F1 $ 777         
   ADRL_F2 $ 778            ADRL_F3 $ 779            ADRL_FHI $ 780        
   ADRL_G1 $ 781            ADRL_G2 $ 782            ADRL_G3 $ 783         
   ADRL_GHI $ 784           ADRL_H1 $ 785            ADRL_H2 $ 786         
   ADRL_H3 $ 787            ADRL_HHI $ 788           ADRL_I1 $ 789         
   ADRL_I2 $ 790            ADRL_I3 $ 791            ADRL_IHI $ 792        
   ADRL_J1 $ 793            ADRL_J2 $ 794            ADRL_J3 $ 795         
   ADRL_JHI $ 796           ADRL_K1 $ 797            ADRL_K2 $ 798         
   ADRL_K3 $ 799            ADRL_KHI $ 800           ADRL_L1 $ 801         
   ADRL_L2 $ 802            ADRL_L3 $ 803            ADRL_LHI $ 804        
   ADRL_M1 $ 805            ADRL_M2 $ 806            ADRL_M3 $ 807         
   ADRL_MHI $ 808           ADRL_N1 $ 809            ADRL_N2 $ 810         
   ADRL_N3 $ 811            ADRL_NHI $ 812           ADRL_O1 $ 813         
   ADRL_O2 $ 814            ADRL_O3 $ 815            ADRL_OHI $ 816        
   ADRL_P1 $ 817            ADRL_P2 $ 818            ADRL_P3 $ 819         
   ADRL_PHI $ 820           BASERL1 $ 821            BASERL2 $ 822         
   BASERL3 $ 823            BASERLHI $ 824           ADSL_B1 $ 825         
   ADSL_B2 $ 826            ADSL_B3 $ 827            ADSL_BHI $ 828        
   ADSL_C1 $ 829-830        ADSL_C2 $ 831            ADSL_C3 $ 832         
   ADSL_CHI $ 833-834       ADSL_D1 $ 835            ADSL_D2 $ 836         
   ADSL_D3 $ 837            ADSL_DHI $ 838           ADSL_E1 $ 839         
   ADSL_E2 $ 840            ADSL_E3 $ 841            ADSL_EHI $ 842        
   ADSL_F1 $ 843            ADSL_F2 $ 844            ADSL_F3 $ 845         
   ADSL_FHI $ 846           ADSL_G1 $ 847            ADSL_G2 $ 848         
   ADSL_G3 $ 849            ADSL_GHI $ 850           ADSL_H1 $ 851         
   ADSL_H2 $ 852            ADSL_H3 $ 853            ADSL_HHI $ 854        
   ADSL_I1 $ 855            ADSL_I2 $ 856            ADSL_I3 $ 857         
   ADSL_IHI $ 858           ADSL_J1 $ 859            ADSL_J2 $ 860         
   ADSL_J3 $ 861            ADSL_JHI $ 862           ADSL_K1 $ 863-864     
   ADSL_K2 $ 865            ADSL_K3 $ 866            ADSL_KHI $ 867-868    
   ADSL_L1 $ 869            ADSL_L2 $ 870            ADSL_L3 $ 871         
   ADSL_LHI $ 872           ADSL_M1 $ 873            ADSL_M2 $ 874         
   ADSL_M3 $ 875            ADSL_MHI $ 876           ADSL_N1 $ 877         
   ADSL_N2 $ 878            ADSL_N3 $ 879            ADSL_NHI $ 880        
   ADSL_O1 $ 881            ADSL_O2 $ 882            ADSL_O3 $ 883         
   ADSL_OHI $ 884           ADSL_P1 $ 885            ADSL_P2 $ 886         
   ADSL_P3 $ 887            ADSL_PHI $ 888           BASESL1 $ 889         
   BASESL2 $ 890            BASESL3 $ 891            BASESLHI $ 892        
   ADCL_B1 $ 893            ADCL_B2 $ 894            ADCL_B3 $ 895         
   ADCL_BHI $ 896           ADCL_C1 $ 897            ADCL_C2 $ 898         
   ADCL_C3 $ 899            ADCL_CHI $ 900           ADCL_D1 $ 901         
   ADCL_D2 $ 902            ADCL_D3 $ 903            ADCL_DHI $ 904        
   ADCL_E1 $ 905            ADCL_E2 $ 906            ADCL_E3 $ 907         
   ADCL_EHI $ 908           ADCL_F1 $ 909            ADCL_F2 $ 910         
   ADCL_F3 $ 911            ADCL_FHI $ 912           ADCL_G1 $ 913         
   ADCL_G2 $ 914            ADCL_G3 $ 915            ADCL_GHI $ 916        
   ADCL_H1 $ 917            ADCL_H2 $ 918            ADCL_H3 $ 919         
   ADCL_HHI $ 920           ADCL_I1 $ 921            ADCL_I2 $ 922         
   ADCL_I3 $ 923            ADCL_IHI $ 924           ADCL_J1 $ 925         
   ADCL_J2 $ 926            ADCL_J3 $ 927            ADCL_JHI $ 928        
   ADCL_K1 $ 929            ADCL_K2 $ 930            ADCL_K3 $ 931         
   ADCL_KHI $ 932           ADCL_L1 $ 933            ADCL_L2 $ 934         
   ADCL_L3 $ 935            ADCL_LHI $ 936           ADCL_M1 $ 937         
   ADCL_M2 $ 938            ADCL_M3 $ 939            ADCL_MHI $ 940        
   ADCL_N1 $ 941            ADCL_N2 $ 942            ADCL_N3 $ 943         
   ADCL_NHI $ 944           ADCL_O1 $ 945            ADCL_O2 $ 946         
   ADCL_O3 $ 947            ADCL_OHI $ 948           ADCL_P1 $ 949         
   ADCL_P2 $ 950            ADCL_P3 $ 951            ADCL_PHI $ 952        
   BASECL1 $ 953            BASECL2 $ 954-956        BASECL3 $ 957-959     
   BASECLHI $ 960           GDLINE1 $ 961-965        GDLINE2 $ 966-970     
   GDLINE3 $ 971-975        GDSTAT1 $ 976-980        GDSTAT2 $ 981-985     
   GDSTAT3 $ 986-990        GDREF1 $ 991-995         GDREF2 $ 996          
   GDREF3 $ 997             GDCROS1 $ 998            GDCROS2 $ 999         
   GDCROS3 $ 1000           NOCOMP  1001             GDLINEHI $ 1002-1006  
   GDSTATHI $ 1007-1011     GDREFHI $ 1012-1016      GDCROSHI $ 1017       
   SMIN1  1018-1021         SMIN2  1022              SMIN3  1023           
   SMIN4  1024              SMIN5  1025              SMIN6  1026           
   SMIN7  1027              SMIN8  1028              SMIN9  1029           
   SMIN10  1030             SMIN11  1031             SMIN12  1032          
   SMIN13  1033             SMIN14  1034             SMIN15  1035          
   SMIN16  1036             SMIN17  1037             SMIN18  1038          
   SMIN19  1039             SMIN20  1040             SMIN21  1041          
   SMIN22  1042             SMIN23  1043             SMIN24  1044          
   SMIN25  1045             SMIN26  1046             SMIN27  1047          
   SMIN28  1048             SMIN29  1049             SMIN30  1050          
   SMIN31  1051             SMIN32  1052             SMIN33  1053          
   SMIN34  1054             SMIN35  1055             SMIN36  1056          
   SMIN37  1057             SMIN38  1058             SMIN39  1059          
   SMIN40  1060             SMIN41  1061             SMIN42  1062          
   SMIN43  1063             SMIN44  1064             SMIN45  1065          
   SMIN46  1066             SMIN47  1067             SMIN48  1068          
   SMIN49  1069             SMIN50  1070             SMIN51  1071          
   SMIN52  1072             SMIN53  1073             SMIN54  1074          
   SMIN55  1075             SMIN56  1076             SMIN57  1077          
   SMIN58  1078             SMIN59  1079             SMIN60  1080          
   SMIN61  1081             SMIN62  1082             SMIN63  1083          
   SMIN64  1084             SMIN65  1085             SMIN66  1086          
   SMIN67  1087             SMIN68  1088             SMIN69  1089          
   SMIN70  1090             SMIN71  1091             SMIN72  1092          
   SMIN73  1093             SMIN74  1094             SMIN75  1095          
   SMIN76  1096             SMIN77  1097             SMIN78  1098          
   SMIN79  1099             SMIN80  1100             SMIN81  1101          
   SMIN82  1102             SMIN83  1103             SMIN84  1104          
   SMIN85  1105             SMIN86  1106             SMIN87  1107          
   SMIN88  1108             SMIN89  1109             SMIN90  1110          
   SMIN91  1111             SMIN92  1112             SMIN93  1113          
   SMIN94  1114             SMIN95  1115             SMIN96  1116          
   SMIN97  1117             SMIN98  1118             SMIN99  1119          
   SMIN100  1120            SMIN101  1121            SMIN102  1122         
   SMIN103  1123            SMIN104  1124            SMIN105  1125         
   SMIN106  1126            SMIN107  1127            SMIN108  1128         
   SMIN109  1129            SMIN110  1130            SMIN111  1131         
   SMIN112  1132            SMIN113  1133            SMIN114  1134         
   SMIN115  1135            SMIN116  1136            SMIN117  1137         
   SMIN118  1138            SMIN119  1139            SMIN120  1140         
   SMIN121  1141            SMIN122  1142            SMAX1  1143-1150      
   SMAX2  1151-1158         SMAX3  1159-1164         SMAX4  1165-1170      
   SMAX5  1171-1176         SMAX6  1177-1182         SMAX7  1183-1188      
   SMAX8  1189-1194         SMAX9  1195-1200         SMAX10  1201-1206     
   SMAX11  1207-1212        SMAX12  1213-1218        SMAX13  1219-1224     
   SMAX14  1225-1230        SMAX15  1231-1236        SMAX16  1237-1242     
   SMAX17  1243-1248        SMAX18  1249-1254        SMAX19  1255-1260     
   SMAX20  1261-1266        SMAX21  1267-1272        SMAX22  1273-1278     
   SMAX23  1279-1284        SMAX24  1285-1290        SMAX25  1291-1296     
   SMAX26  1297-1302        SMAX27  1303-1308        SMAX28  1309-1314     
   SMAX29  1315-1320        SMAX30  1321-1326        SMAX31  1327-1332     
   SMAX32  1333-1338        SMAX33  1339-1344        SMAX34  1345-1350     
   SMAX35  1351-1356        SMAX36  1357-1362        SMAX37  1363-1368     
   SMAX38  1369-1374        SMAX39  1375-1380        SMAX40  1381-1386     
   SMAX41  1387-1392        SMAX42  1393-1398        SMAX43  1399-1404     
   SMAX44  1405-1410        SMAX45  1411-1416        SMAX46  1417-1422     
   SMAX47  1423-1428        SMAX48  1429-1434        SMAX49  1435-1440     
   SMAX50  1441-1446        SMAX51  1447-1452        SMAX52  1453-1458     
   SMAX53  1459-1464        SMAX54  1465-1470        SMAX55  1471-1476     
   SMAX56  1477-1482        SMAX57  1483-1488        SMAX58  1489-1494     
   SMAX59  1495-1500        SMAX60  1501-1506        SMAX61  1507-1512     
   SMAX62  1513-1518        SMAX63  1519-1524        SMAX64  1525-1530     
   SMAX65  1531-1536        SMAX66  1537-1542        SMAX67  1543-1548     
   SMAX68  1549-1554        SMAX69  1555-1560        SMAX70  1561-1566     
   SMAX71  1567-1572        SMAX72  1573-1578        SMAX73  1579-1584     
   SMAX74  1585-1590        SMAX75  1591-1596        SMAX76  1597-1602     
   SMAX77  1603-1608        SMAX78  1609-1614        SMAX79  1615-1620     
   SMAX80  1621-1626        SMAX81  1627-1632        SMAX82  1633-1638     
   SMAX83  1639-1644        SMAX84  1645-1650        SMAX85  1651-1656     
   SMAX86  1657-1662        SMAX87  1663-1668        SMAX88  1669-1674     
   SMAX89  1675-1680        SMAX90  1681-1686        SMAX91  1687-1692     
   SMAX92  1693-1698        SMAX93  1699-1704        SMAX94  1705-1710     
   SMAX95  1711-1716        SMAX96  1717-1722        SMAX97  1723-1728     
   SMAX98  1729-1734        SMAX99  1735-1740        SMAX100  1741-1746    
   SMAX101  1747-1752       SMAX102  1753-1758       SMAX103  1759-1764    
   SMAX104  1765-1770       SMAX105  1771-1776       SMAX106  1777-1782    
   SMAX107  1783-1788       SMAX108  1789-1794       SMAX109  1795-1800    
   SMAX110  1801-1806       SMAX111  1807-1812       SMAX112  1813-1818    
   SMAX113  1819-1824       SMAX114  1825-1830       SMAX115  1831-1836    
   SMAX116  1837-1842       SMAX117  1843-1848       SMAX118  1849-1854    
   SMAX119  1855-1860       SMAX120  1861-1866       SMAX121  1867-1872    
   SMAX122  1873-1878       STA1_1 $ 1879-1889       STA1_2 $ 1890-1899    
   STA1_3 $ 1900-1908       STA1_4 $ 1909-1917       STA1_5 $ 1918-1926    
   STA1_6 $ 1927-1935       STA1_7 $ 1936-1944       STA1_8 $ 1945-1953    
   STA1_9 $ 1954-1962       STA1_10 $ 1963-1971      STA1_11 $ 1972-1980   
   STA1_12 $ 1981-1989      STA1_13 $ 1990-1998      STA1_14 $ 1999-2007   
   STA1_15 $ 2008-2016      STA1_16 $ 2017-2025      STA1_17 $ 2026-2034   
   STA1_18 $ 2035-2043      STA1_19 $ 2044-2052      STA1_20 $ 2053-2061   
   STA1_21 $ 2062-2070      STA1_22 $ 2071-2079      STA1_23 $ 2080-2088   
   STA1_24 $ 2089-2096      STA1_25 $ 2097-2104      STA1_26 $ 2105-2112   
   STA1_27 $ 2113-2120      STA1_28 $ 2121-2128      STA1_29 $ 2129-2136   
   STA1_30 $ 2137-2144      STA1_31 $ 2145-2152      STA1_32 $ 2153-2160   
   STA1_33 $ 2161-2168      STA1_34 $ 2169-2176      STA1_35 $ 2177-2184   
   STA1_36 $ 2185-2192      STA1_37 $ 2193-2200      STA1_38 $ 2201-2208   
   STA1_39 $ 2209-2216      STA1_40 $ 2217-2224      STA1_41 $ 2225-2232   
   STA1_42 $ 2233-2240      STA1_43 $ 2241-2248      STA1_44 $ 2249-2256   
   STA1_45 $ 2257-2264      STA1_46 $ 2265-2272      STA1_47 $ 2273-2280   
   STA1_48 $ 2281-2288      STA1_49 $ 2289-2296      STA1_50 $ 2297-2304   
   STA1_51 $ 2305-2312      STA1_52 $ 2313-2320      STA1_53 $ 2321-2328   
   STA1_54 $ 2329-2336      STA1_55 $ 2337-2344      STA1_56 $ 2345-2352   
   STA1_57 $ 2353-2360      STA1_58 $ 2361-2368      STA1_59 $ 2369-2376   
   STA1_60 $ 2377-2384      STA1_61 $ 2385-2392      STA1_62 $ 2393-2400   
   STA1_63 $ 2401-2408      STA1_64 $ 2409-2416      STA1_65 $ 2417-2424   
   STA1_66 $ 2425-2432      STA1_67 $ 2433-2440      STA1_68 $ 2441-2448   
   STA1_69 $ 2449-2456      STA1_70 $ 2457-2464      STA1_71 $ 2465-2472   
   STA1_72 $ 2473-2480      STA1_73 $ 2481-2488      STA1_74 $ 2489-2496   
   STA1_75 $ 2497-2504      STA1_76 $ 2505-2512      STA1_77 $ 2513-2520   
   STA1_78 $ 2521-2528      STA1_79 $ 2529-2536      STA1_80 $ 2537-2544   
   STA1_81 $ 2545-2552      STA1_82 $ 2553-2560      STA1_83 $ 2561-2568   
   STA1_84 $ 2569-2576      STA1_85 $ 2577-2584      STA1_86 $ 2585-2592   
   STA1_87 $ 2593-2600      STA1_88 $ 2601-2608      STA1_89 $ 2609-2616   
   STA1_90 $ 2617-2624      STA1_91 $ 2625-2632      STA1_92 $ 2633-2640   
   STA1_93 $ 2641-2648      STA1_94 $ 2649-2656      STA1_95 $ 2657-2664   
   STA1_96 $ 2665-2672      STA1_97 $ 2673-2680      STA1_98 $ 2681-2688   
   STA1_99 $ 2689-2696      STA1_100 $ 2697-2704     STA1_101 $ 2705-2712  
   STA1_102 $ 2713-2720     STA1_103 $ 2721-2728     STA1_104 $ 2729-2736  
   STA1_105 $ 2737-2744     STA1_106 $ 2745-2752     STA1_107 $ 2753-2760  
   STA1_108 $ 2761-2768     STA1_109 $ 2769-2776     STA1_110 $ 2777-2784  
   STA1_111 $ 2785-2792     STA1_112 $ 2793-2800     STA1_113 $ 2801-2808  
   STA1_114 $ 2809-2816     STA1_115 $ 2817-2824     STA1_116 $ 2825-2832  
   STA1_117 $ 2833-2840     STA1_118 $ 2841-2848     STA1_119 $ 2849-2856  
   STA1_120 $ 2857-2864     STA1_121 $ 2865-2872     STA1_122 $ 2873-2880  
   STA2_1 $ 2881-2890       STA2_2 $ 2891-2900       STA2_3 $ 2901-2910    
   STA2_4 $ 2911-2920       STA2_5 $ 2921-2931       STA2_6 $ 2932-2942    
   STA2_7 $ 2943-2953       STA2_8 $ 2954-2963       STA2_9 $ 2964-2973    
   STA2_10 $ 2974-2984      STA2_11 $ 2985-2994      STA2_12 $ 2995-3004   
   STA2_13 $ 3005-3015      STA2_14 $ 3016-3026      STA2_15 $ 3027-3037   
   STA2_16 $ 3038-3048      STA2_17 $ 3049-3059      STA2_18 $ 3060-3070   
   STA2_19 $ 3071-3081      STA2_20 $ 3082-3092      STA2_21 $ 3093-3103   
   STA2_22 $ 3104-3114      STA2_23 $ 3115-3125      STA2_24 $ 3126-3133   
   STA2_25 $ 3134-3141      STA2_26 $ 3142-3149      STA2_27 $ 3150-3157   
   STA2_28 $ 3158-3165      STA2_29 $ 3166-3173      STA2_30 $ 3174-3181   
   STA2_31 $ 3182-3189      STA2_32 $ 3190-3197      STA2_33 $ 3198-3205   
   STA2_34 $ 3206-3213      STA2_35 $ 3214-3221      STA2_36 $ 3222-3229   
   STA2_37 $ 3230-3237      STA2_38 $ 3238-3245      STA2_39 $ 3246-3253   
   STA2_40 $ 3254-3261      STA2_41 $ 3262-3269      STA2_42 $ 3270-3277   
   STA2_43 $ 3278-3285      STA2_44 $ 3286-3293      STA2_45 $ 3294-3301   
   STA2_46 $ 3302-3309      STA2_47 $ 3310-3317      STA2_48 $ 3318-3325   
   STA2_49 $ 3326-3333      STA2_50 $ 3334-3341      STA2_51 $ 3342-3349   
   STA2_52 $ 3350-3357      STA2_53 $ 3358-3365      STA2_54 $ 3366-3373   
   STA2_55 $ 3374-3381      STA2_56 $ 3382-3389      STA2_57 $ 3390-3397   
   STA2_58 $ 3398-3405      STA2_59 $ 3406-3413      STA2_60 $ 3414-3421   
   STA2_61 $ 3422-3429      STA2_62 $ 3430-3437      STA2_63 $ 3438-3445   
   STA2_64 $ 3446-3453      STA2_65 $ 3454-3461      STA2_66 $ 3462-3469   
   STA2_67 $ 3470-3477      STA2_68 $ 3478-3485      STA2_69 $ 3486-3493   
   STA2_70 $ 3494-3501      STA2_71 $ 3502-3509      STA2_72 $ 3510-3517   
   STA2_73 $ 3518-3525      STA2_74 $ 3526-3533      STA2_75 $ 3534-3541   
   STA2_76 $ 3542-3549      STA2_77 $ 3550-3557      STA2_78 $ 3558-3565   
   STA2_79 $ 3566-3573      STA2_80 $ 3574-3581      STA2_81 $ 3582-3589   
   STA2_82 $ 3590-3597      STA2_83 $ 3598-3605      STA2_84 $ 3606-3613   
   STA2_85 $ 3614-3621      STA2_86 $ 3622-3629      STA2_87 $ 3630-3637   
   STA2_88 $ 3638-3645      STA2_89 $ 3646-3653      STA2_90 $ 3654-3661   
   STA2_91 $ 3662-3669      STA2_92 $ 3670-3677      STA2_93 $ 3678-3685   
   STA2_94 $ 3686-3693      STA2_95 $ 3694-3701      STA2_96 $ 3702-3709   
   STA2_97 $ 3710-3717      STA2_98 $ 3718-3725      STA2_99 $ 3726-3733   
   STA2_100 $ 3734-3741     STA2_101 $ 3742-3749     STA2_102 $ 3750-3757  
   STA2_103 $ 3758-3765     STA2_104 $ 3766-3773     STA2_105 $ 3774-3781  
   STA2_106 $ 3782-3789     STA2_107 $ 3790-3797     STA2_108 $ 3798-3805  
   STA2_109 $ 3806-3813     STA2_110 $ 3814-3821     STA2_111 $ 3822-3829  
   STA2_112 $ 3830-3837     STA2_113 $ 3838-3845     STA2_114 $ 3846-3853  
   STA2_115 $ 3854-3861     STA2_116 $ 3862-3869     STA2_117 $ 3870-3877  
   STA2_118 $ 3878-3885     STA2_119 $ 3886-3893     STA2_120 $ 3894-3901  
   STA2_121 $ 3902-3909     STA2_122 $ 3910-3917     STA3_1 $ 3918-3926    
   STA3_2 $ 3927-3936       STA3_3 $ 3937-3946       STA3_4 $ 3947-3956    
   STA3_5 $ 3957-3966       STA3_6 $ 3967-3976       STA3_7 $ 3977-3986    
   STA3_8 $ 3987-3996       STA3_9 $ 3997-4006       STA3_10 $ 4007-4016   
   STA3_11 $ 4017-4026      STA3_12 $ 4027-4036      STA3_13 $ 4037-4047   
   STA3_14 $ 4048-4058      STA3_15 $ 4059-4069      STA3_16 $ 4070-4080   
   STA3_17 $ 4081-4091      STA3_18 $ 4092-4102      STA3_19 $ 4103-4113   
   STA3_20 $ 4114-4124      STA3_21 $ 4125-4135      STA3_22 $ 4136-4146   
   STA3_23 $ 4147-4157      STA3_24 $ 4158-4161      STA3_25 $ 4162-4165   
   STA3_26 $ 4166-4169      STA3_27 $ 4170-4173      STA3_28 $ 4174-4177   
   STA3_29 $ 4178-4181      STA3_30 $ 4182-4185      STA3_31 $ 4186-4189   
   STA3_32 $ 4190-4193      STA3_33 $ 4194-4197      STA3_34 $ 4198-4201   
   STA3_35 $ 4202-4205      STA3_36 $ 4206-4209      STA3_37 $ 4210-4213   
   STA3_38 $ 4214-4217      STA3_39 $ 4218-4221      STA3_40 $ 4222-4225   
   STA3_41 $ 4226           STA3_42 $ 4227           STA3_43 $ 4228        
   STA3_44 $ 4229           STA3_45 $ 4230           STA3_46 $ 4231        
   STA3_47 $ 4232           STA3_48 $ 4233           STA3_49 $ 4234        
   STA3_50 $ 4235           STA3_51 $ 4236           STA3_52 $ 4237        
   STA3_53 $ 4238           STA3_54 $ 4239           STA3_55 $ 4240        
   STA3_56 $ 4241           STA3_57 $ 4242           STA3_58 $ 4243        
   STA3_59 $ 4244           STA3_60 $ 4245           STA3_61 $ 4246        
   STA3_62 $ 4247           STA3_63 $ 4248           STA3_64 $ 4249        
   STA3_65 $ 4250           STA3_66 $ 4251           STA3_67 $ 4252        
   STA3_68 $ 4253           STA3_69 $ 4254           STA3_70 $ 4255        
   STA3_71 $ 4256           STA3_72 $ 4257           STA3_73 $ 4258        
   STA3_74 $ 4259           STA3_75 $ 4260           STA3_76 $ 4261        
   STA3_77 $ 4262           STA3_78 $ 4263           STA3_79 $ 4264        
   STA3_80 $ 4265           STA3_81 $ 4266           STA3_82 $ 4267        
   STA3_83 $ 4268           STA3_84 $ 4269           STA3_85 $ 4270        
   STA3_86 $ 4271           STA3_87 $ 4272           STA3_88 $ 4273        
   STA3_89 $ 4274           STA3_90 $ 4275           STA3_91 $ 4276        
   STA3_92 $ 4277           STA3_93 $ 4278           STA3_94 $ 4279        
   STA3_95 $ 4280           STA3_96 $ 4281           STA3_97 $ 4282        
   STA3_98 $ 4283           STA3_99 $ 4284           STA3_100 $ 4285       
   STA3_101 $ 4286          STA3_102 $ 4287          STA3_103 $ 4288       
   STA3_104 $ 4289          STA3_105 $ 4290          STA3_106 $ 4291       
   STA3_107 $ 4292          STA3_108 $ 4293          STA3_109 $ 4294       
   STA3_110 $ 4295          STA3_111 $ 4296          STA3_112 $ 4297       
   STA3_113 $ 4298          STA3_114 $ 4299          STA3_115 $ 4300       
   STA3_116 $ 4301          STA3_117 $ 4302          STA3_118 $ 4303       
   STA3_119 $ 4304          STA3_120 $ 4305          STA3_121 $ 4306       
   STA3_122 $ 4307          NWSTAT1 $ 4308-4318      NWSTAT2 $ 4319-4328   
   NWSTAT3 $ 4329-4338      NWSTAT4 $ 4339-4349      NWSTAT5 $ 4350-4359   
   NWSTAT6 $ 4360-4369      NWSTAT7 $ 4370-4380      NWSTAT8 $ 4381-4391   
   NWSTAT9 $ 4392-4401      NOUSTAT  4402            BASEFINE  4403-4411   
   CH2APP  4412             CH8FINGD  4413           CMSRVORD  4414        
   COMPLYPR  4415           COSTASSM  4416           FINOFFST  4417        
   FORFEITR  4418-4425      GLFINMAX  4426-4434      GLFINMIN  4435-4443   
   OFFENSE1  4444-4445      OFFENSE2  4446-4447      OFFENSE3  4448        
   REMEDORD  4449-4451      VICTNOTE  4452           BOOKPOST  4453        
   BOOKERCD  4454-4455      QUARTER  4456            REAS1  4457-4459      
   REAS2  4460-4462         REAS3  4463-4465         REAS4  4466           
   REAS5  4467              REAS6  4468              REAS7  4469           
   REAS8  4470              REAS9  4471              REAS10  4472          
   INPLEA1  4473            INPLEA2  4474            INPLEA3  4475         
   INPLEA4  4476            INPLEA5  4477            INPLEA6  4478         
   INPLEA7  4479            INPLEA8  4480            INPLEA9  4481         
   INPLEA10  4482           INPLEA11  4483           INPLEA12  4484        
   INNOPL1  4485            INNOPL2  4486            INNOPL3  4487         
   INNOPL4  4488            INNOPL5  4489            INNOPL6  4490         
   INNOPL7  4491            INNOPL8  4492            INNOPL9  4493         
   INNOPL10  4494           INNOPL11  4495           INNOPL12  4496        
   SENTYR  4497-4500        TYPEOTTX $ 4501-4700     BOOKER2  4701         
   BOOKER3  4702            RETEXT1 $ 4703           RETEXT2 $ 4704        
   RETEXT3 $ 4705           RETEXT4 $ 4706           RETEXT5 $ 4707        
   RETEXT6 $ 4708           RETEXT7 $ 4709           RETEXT8 $ 4710        
   RETEXT9 $ 4711           RETEXT10 $ 4712          NEWCNVTN  4713        
   RESTCAT  4714            FINECAT  4715            SUSFNCAT  4716        
   LCAT1  4717              LCAT2  4718              LCAT3  4719           
   LCATHI  4720             LCATS1  4721             LCATS2  4722          
   LCATS3  4723             LCATSHI  4724            LCATR1  4725          
   LCATR2  4726             LCATR3  4727             LCATRHI  4728         
   LCATC1  4729             LCATC2  4730             LCATC3  4731          
   LCATCHI  4732          ;                       

LENGTH
   DISGORGE 3               CPIDN 4                  AMENDYR 4             
   PSR 3                    JANDC 3                  PLEA 3                
   REASONS 3                INDICT 3                 SENTRANS 3            
   WRKSHT 3                 INCORPYR 4               INCORLOC 3            
   ORGTYPE 3                BUSCLAS 4                FTEMNUM 4             
   FTEMSIGN 3               SELFREP 3                HSMISCND 3            
   PRCRIME 3                PRCIVIL 3                OWNSTRCT 3            
   FINSTDS 3                FINSTDO 3                PRIMOFF 3             
   NOCOUNTS 4               SOURCES 3                OFFLVL 3              
   DETBFINE 3               TOLERNCE 3               HISTORY 3             
   VIOLATE 3                OBSTRUCT 3               COMPLY 3              
   ACCEPT 3                 CCULPSCO 3               FCULPSCO 3            
   DISPOSIT 3               PROBATN 3                COFI 3                
   PROBMON 3                ORDERCE 3                TYPEOTHS 3            
   CRIMPURP 3               CANTPAY 3                DEPSOR 3              
   ADJOFL1 3                ADJOFL2 3                ADJOFL3 3             
   ADJOFLHI 3               ADJ_B1 3                 ADJ_B2 3              
   ADJ_B3 3                 ADJ_BHI 3                ADJ_C1 3              
   ADJ_C2 3                 ADJ_C3 3                 ADJ_CHI 3             
   ADJ_D1 3                 ADJ_D2 3                 ADJ_D3 3              
   ADJ_DHI 3                ADJ_E1 3                 ADJ_E2 3              
   ADJ_E3 3                 ADJ_EHI 3                ADJ_F1 3              
   ADJ_F2 3                 ADJ_F3 3                 ADJ_FHI 3             
   ADJ_G1 3                 ADJ_G2 3                 ADJ_G3 3              
   ADJ_GHI 3                ADJ_H1 3                 ADJ_H2 3              
   ADJ_H3 3                 ADJ_HHI 3                ADJ_I1 3              
   ADJ_I2 3                 ADJ_I3 3                 ADJ_IHI 3             
   ADJ_J1 3                 ADJ_J2 3                 ADJ_J3 3              
   ADJ_JHI 3                ADJ_K1 3                 ADJ_K2 3              
   ADJ_K3 3                 ADJ_KHI 3                ADJ_L1 3              
   ADJ_L2 3                 ADJ_L3 3                 ADJ_LHI 3             
   ADJ_M1 3                 ADJ_M2 3                 ADJ_M3 3              
   ADJ_MHI 3                ADJ_N1 3                 ADJ_N2 3              
   ADJ_N3 3                 ADJ_NHI 3                ADJ_O1 3              
   ADJ_O2 3                 ADJ_O3 3                 ADJ_OHI 3             
   ADJ_P1 3                 ADJ_P2 3                 ADJ_P3 3              
   ADJ_PHI 3                BASADJ1 3                BASADJ2 3             
   BASADJ3 3                BASADJHI 3               BASE1 3               
   BASE2 3                  BASE3 3                  BASEHI 3              
   ADJOFR1 3                ADJOFR2 3                ADJOFR3 3             
   ADJOFRHI 3               ADJR_B1 3                ADJR_B2 3             
   ADJR_B3 3                ADJR_BHI 3               ADJR_C1 3             
   ADJR_C2 3                ADJR_C3 3                ADJR_CHI 3            
   ADJR_D1 3                ADJR_D2 3                ADJR_D3 3             
   ADJR_DHI 3               ADJR_E1 3                ADJR_E2 3             
   ADJR_E3 3                ADJR_EHI 3               ADJR_F1 3             
   ADJR_F2 3                ADJR_F3 3                ADJR_FHI 3            
   ADJR_G1 3                ADJR_G2 3                ADJR_G3 3             
   ADJR_GHI 3               ADJR_H1 3                ADJR_H2 3             
   ADJR_H3 3                ADJR_HHI 3               ADJR_I1 3             
   ADJR_I2 3                ADJR_I3 3                ADJR_IHI 3            
   ADJR_J1 3                ADJR_J2 3                ADJR_J3 3             
   ADJR_JHI 3               ADJR_K1 3                ADJR_K2 3             
   ADJR_K3 3                ADJR_KHI 3               ADJR_L1 3             
   ADJR_L2 3                ADJR_L3 3                ADJR_LHI 3            
   ADJR_M1 3                ADJR_M2 3                ADJR_M3 3             
   ADJR_MHI 3               ADJR_N1 3                ADJR_N2 3             
   ADJR_N3 3                ADJR_NHI 3               ADJR_O1 3             
   ADJR_O2 3                ADJR_O3 3                ADJR_OHI 3            
   ADJR_P1 3                ADJR_P2 3                ADJR_P3 3             
   ADJR_PHI 3               BASADR1 3                BASADR2 3             
   BASADR3 3                BASADRHI 3               BASER1 3              
   BASER2 3                 BASER3 3                 BASERHI 3             
   ADJOFS1 3                ADJOFS2 3                ADJOFS3 3             
   ADJOFSHI 3               ADJS_B1 3                ADJS_B2 3             
   ADJS_B3 3                ADJS_BHI 3               ADJS_C1 3             
   ADJS_C2 3                ADJS_C3 3                ADJS_CHI 3            
   ADJS_D1 3                ADJS_D2 3                ADJS_D3 3             
   ADJS_DHI 3               ADJS_E1 3                ADJS_E2 3             
   ADJS_E3 3                ADJS_EHI 3               ADJS_F1 3             
   ADJS_F2 3                ADJS_F3 3                ADJS_FHI 3            
   ADJS_G1 3                ADJS_G2 3                ADJS_G3 3             
   ADJS_GHI 3               ADJS_H1 3                ADJS_H2 3             
   ADJS_H3 3                ADJS_HHI 3               ADJS_I1 3             
   ADJS_I2 3                ADJS_I3 3                ADJS_IHI 3            
   ADJS_J1 3                ADJS_J2 3                ADJS_J3 3             
   ADJS_JHI 3               ADJS_K1 3                ADJS_K2 3             
   ADJS_K3 3                ADJS_KHI 3               ADJS_L1 3             
   ADJS_L2 3                ADJS_L3 3                ADJS_LHI 3            
   ADJS_M1 3                ADJS_M2 3                ADJS_M3 3             
   ADJS_MHI 3               ADJS_N1 3                ADJS_N2 3             
   ADJS_N3 3                ADJS_NHI 3               ADJS_O1 3             
   ADJS_O2 3                ADJS_O3 3                ADJS_OHI 3            
   ADJS_P1 3                ADJS_P2 3                ADJS_P3 3             
   ADJS_PHI 3               BASADS1 3                BASADS2 3             
   BASADS3 3                BASADSHI 3               BASES1 3              
   BASES2 3                 BASES3 3                 BASESHI 3             
   ADJOFC1 3                ADJOFC2 3                ADJOFC3 3             
   ADJOFCHI 3               ADJC_B1 3                ADJC_B2 3             
   ADJC_B3 3                ADJC_BHI 3               ADJC_C1 3             
   ADJC_C2 3                ADJC_C3 3                ADJC_CHI 3            
   ADJC_D1 3                ADJC_D2 3                ADJC_D3 3             
   ADJC_DHI 3               ADJC_E1 3                ADJC_E2 3             
   ADJC_E3 3                ADJC_EHI 3               ADJC_F1 3             
   ADJC_F2 3                ADJC_F3 3                ADJC_FHI 3            
   ADJC_G1 3                ADJC_G2 3                ADJC_G3 3             
   ADJC_GHI 3               ADJC_H1 3                ADJC_H2 3             
   ADJC_H3 3                ADJC_HHI 3               ADJC_I1 3             
   ADJC_I2 3                ADJC_I3 3                ADJC_IHI 3            
   ADJC_J1 3                ADJC_J2 3                ADJC_J3 3             
   ADJC_JHI 3               ADJC_K1 3                ADJC_K2 3             
   ADJC_K3 3                ADJC_KHI 3               ADJC_L1 3             
   ADJC_L2 3                ADJC_L3 3                ADJC_LHI 3            
   ADJC_M1 3                ADJC_M2 3                ADJC_M3 3             
   ADJC_MHI 3               ADJC_N1 3                ADJC_N2 3             
   ADJC_N3 3                ADJC_NHI 3               ADJC_O1 3             
   ADJC_O2 3                ADJC_O3 3                ADJC_OHI 3            
   ADJC_P1 3                ADJC_P2 3                ADJC_P3 3             
   ADJC_PHI 3               BASADC1 3                BASADC2 3             
   BASADC3 3                BASADCHI 3               BASEC1 3              
   BASEC2 3                 BASEC3 3                 BASECHI 3             
   NOCOMP 3                 SMIN1 4                  SMIN2 3               
   SMIN3 3                  SMIN4 3                  SMIN5 3               
   SMIN6 3                  SMIN7 3                  SMIN8 3               
   SMIN9 3                  SMIN10 3                 SMIN11 3              
   SMIN12 3                 SMIN13 3                 SMIN14 3              
   SMIN15 3                 SMIN16 3                 SMIN17 3              
   SMIN18 3                 SMIN19 3                 SMIN20 3              
   SMIN21 3                 SMIN22 3                 SMIN23 3              
   SMIN24 3                 SMIN25 3                 SMIN26 3              
   SMIN27 3                 SMIN28 3                 SMIN29 3              
   SMIN30 3                 SMIN31 3                 SMIN32 3              
   SMIN33 3                 SMIN34 3                 SMIN35 3              
   SMIN36 3                 SMIN37 3                 SMIN38 3              
   SMIN39 3                 SMIN40 3                 SMIN41 3              
   SMIN42 3                 SMIN43 3                 SMIN44 3              
   SMIN45 3                 SMIN46 3                 SMIN47 3              
   SMIN48 3                 SMIN49 3                 SMIN50 3              
   SMIN51 3                 SMIN52 3                 SMIN53 3              
   SMIN54 3                 SMIN55 3                 SMIN56 3              
   SMIN57 3                 SMIN58 3                 SMIN59 3              
   SMIN60 3                 SMIN61 3                 SMIN62 3              
   SMIN63 3                 SMIN64 3                 SMIN65 3              
   SMIN66 3                 SMIN67 3                 SMIN68 3              
   SMIN69 3                 SMIN70 3                 SMIN71 3              
   SMIN72 3                 SMIN73 3                 SMIN74 3              
   SMIN75 3                 SMIN76 3                 SMIN77 3              
   SMIN78 3                 SMIN79 3                 SMIN80 3              
   SMIN81 3                 SMIN82 3                 SMIN83 3              
   SMIN84 3                 SMIN85 3                 SMIN86 3              
   SMIN87 3                 SMIN88 3                 SMIN89 3              
   SMIN90 3                 SMIN91 3                 SMIN92 3              
   SMIN93 3                 SMIN94 3                 SMIN95 3              
   SMIN96 3                 SMIN97 3                 SMIN98 3              
   SMIN99 3                 SMIN100 3                SMIN101 3             
   SMIN102 3                SMIN103 3                SMIN104 3             
   SMIN105 3                SMIN106 3                SMIN107 3             
   SMIN108 3                SMIN109 3                SMIN110 3             
   SMIN111 3                SMIN112 3                SMIN113 3             
   SMIN114 3                SMIN115 3                SMIN116 3             
   SMIN117 3                SMIN118 3                SMIN119 3             
   SMIN120 3                SMIN121 3                SMIN122 3             
   SMAX1 6                  SMAX2 6                  SMAX3 6               
   SMAX4 6                  SMAX5 6                  SMAX6 6               
   SMAX7 6                  SMAX8 6                  SMAX9 6               
   SMAX10 6                 SMAX11 6                 SMAX12 6              
   SMAX13 6                 SMAX14 6                 SMAX15 6              
   SMAX16 6                 SMAX17 6                 SMAX18 6              
   SMAX19 6                 SMAX20 6                 SMAX21 6              
   SMAX22 6                 SMAX23 6                 SMAX24 6              
   SMAX25 6                 SMAX26 6                 SMAX27 6              
   SMAX28 6                 SMAX29 6                 SMAX30 6              
   SMAX31 6                 SMAX32 6                 SMAX33 6              
   SMAX34 6                 SMAX35 6                 SMAX36 6              
   SMAX37 6                 SMAX38 6                 SMAX39 6              
   SMAX40 6                 SMAX41 6                 SMAX42 6              
   SMAX43 6                 SMAX44 6                 SMAX45 6              
   SMAX46 6                 SMAX47 6                 SMAX48 6              
   SMAX49 6                 SMAX50 6                 SMAX51 6              
   SMAX52 6                 SMAX53 6                 SMAX54 6              
   SMAX55 6                 SMAX56 6                 SMAX57 6              
   SMAX58 6                 SMAX59 6                 SMAX60 6              
   SMAX61 6                 SMAX62 6                 SMAX63 6              
   SMAX64 6                 SMAX65 6                 SMAX66 6              
   SMAX67 6                 SMAX68 6                 SMAX69 6              
   SMAX70 6                 SMAX71 6                 SMAX72 6              
   SMAX73 6                 SMAX74 6                 SMAX75 6              
   SMAX76 6                 SMAX77 6                 SMAX78 6              
   SMAX79 6                 SMAX80 6                 SMAX81 6              
   SMAX82 6                 SMAX83 6                 SMAX84 6              
   SMAX85 6                 SMAX86 6                 SMAX87 6              
   SMAX88 6                 SMAX89 6                 SMAX90 6              
   SMAX91 6                 SMAX92 6                 SMAX93 6              
   SMAX94 6                 SMAX95 6                 SMAX96 6              
   SMAX97 6                 SMAX98 6                 SMAX99 6              
   SMAX100 6                SMAX101 6                SMAX102 6             
   SMAX103 6                SMAX104 6                SMAX105 6             
   SMAX106 6                SMAX107 6                SMAX108 6             
   SMAX109 6                SMAX110 6                SMAX111 6             
   SMAX112 6                SMAX113 6                SMAX114 6             
   SMAX115 6                SMAX116 6                SMAX117 6             
   SMAX118 6                SMAX119 6                SMAX120 6             
   SMAX121 6                SMAX122 6                NOUSTAT 3             
   BASEFINE 6               CH2APP 3                 CH8FINGD 3            
   CMSRVORD 3               COMPLYPR 3               COSTASSM 3            
   FINOFFST 3               FORFEITR 6               GLFINMAX 6            
   GLFINMIN 6               OFFENSE1 3               OFFENSE2 3            
   OFFENSE3 3               REMEDORD 4               VICTNOTE 3            
   BOOKPOST 3               BOOKERCD 3               QUARTER 3             
   REAS1 4                  REAS2 4                  REAS3 4               
   REAS4 3                  REAS5 3                  REAS6 3               
   REAS7 3                  REAS8 3                  REAS9 3               
   REAS10 3                 INPLEA1 3                INPLEA2 3             
   INPLEA3 3                INPLEA4 3                INPLEA5 3             
   INPLEA6 3                INPLEA7 3                INPLEA8 3             
   INPLEA9 3                INPLEA10 3               INPLEA11 3            
   INPLEA12 3               INNOPL1 3                INNOPL2 3             
   INNOPL3 3                INNOPL4 3                INNOPL5 3             
   INNOPL6 3                INNOPL7 3                INNOPL8 3             
   INNOPL9 3                INNOPL10 3               INNOPL11 3            
   INNOPL12 3               SENTYR 4                 BOOKER2 3             
   BOOKER3 3                NEWCNVTN 3               RESTCAT 3             
   FINECAT 3                SUSFNCAT 3               LCAT1 3               
   LCAT2 3                  LCAT3 3                  LCATHI 3              
   LCATS1 3                 LCATS2 3                 LCATS3 3              
   LCATSHI 3                LCATR1 3                 LCATR2 3              
   LCATR3 3                 LCATRHI 3                LCATC1 3              
   LCATC2 3                 LCATC3 3                 LCATCHI 3 ;

         

RUN ;
